==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'أرشفة',
	'archiver_concatener_explications' => 'ستقوم هذه العملية بتجميع إحصاءات زيارات المقالات:',
	'archiver_concatener_ignorer' => 'الزيارات الاحدث من @nb@ سنة لن تتأثر.',
	'archiver_concatener_par_an' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اول يوم من كل سنة.',
	'archiver_concatener_par_mois' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اليوم الأول من كل شهر.',
	'archiver_conseil_sauvegarde' => 'ينصح في البداية بإنشاء نسخة احتياطية من قاعدة البيانات.',
	'archiver_description' => 'توفر هذه الصفحة أدوات لتنظيف او أرشفة إحصاءات الموقع.',
	'archiver_et_nettoyer' => 'أرشفة وتنظيف',
	'archiver_nettoyer' => 'تنظيف',
	'archiver_nettoyer_explications' => 'يحذف اسطر «المصادر» او «الزيارات» العائدة الى مقالات غير موجودة (او محذوفة) في قاعدة البيانات.',
	'archiver_nettoyer_referers_articles' => 'تنظيف مصادر المقالات referers_articles',
	'archiver_nettoyer_visites_articles' => 'تنظيف زيارات المقالات visites_articles',
	'archiver_nombre_lignes' => 'عدد الاسطر',
	'archiver_operation_longue' => 'يمكن ان تستغرق هذه العملية وقتاً طويلاً، خاصة لدي تنفيذها للمرة الاولي.',
	'archiver_operations_irreversibles' => 'لا يمكن التراجع عن هذه العمليات!',

	// B
	'bouton_effacer_referers' => 'حذف الوصلات الداخلة الآتية',
	'bouton_effacer_statistiques' => 'حذف كل الاحصاءات',

	// C
	'csv' => 'سي.اس.في.',

	// D
	'duree_annee_nb' => '@nb@ سنة',
	'duree_annee_un' => '@nb@ سنة',
	'duree_jour_nb' => '@nb@ يوم',
	'duree_jour_un' => '@nb@ يوم',
	'duree_mois_nb' => '@nb@ شهر',
	'duree_mois_un' => '@nb@ شهر',
	'duree_semaine_nb' => '@nb@ أسبوع',
	'duree_semaine_un' => '@nb@ أسبوع',

	// I
	'icone_evolution_visites' => 'تطور الزيارات <br />@visites@ زيارة ',
	'icone_repartition_actuelle' => 'إظهار التوزيع الحالي',
	'icone_repartition_visites' => 'توزيع الزيارات',
	'icone_statistiques_visites' => 'الإحصاءات',
	'info_affichier_visites_articles_plus_visites' => 'إظهار الزيارات المتعلقة <b> بأكثر المقالات زيارة منذ البداية:</ b>',
	'info_comment_lire_tableau' => 'كيفية قراءة هذا الرسم البياني',
	'info_forum_statistiques' => 'إحصاءات الزيارات',
	'info_graphiques' => 'الرسوم البيانية',
	'info_popularite_2' => 'شعبية الموقع:',
	'info_popularite_3' => 'الشعبية: @popularite@؛ الزيارات: @visites@',
	'info_popularite_5' => 'الشعبية:',
	'info_previsions' => 'توقعات:',
	'info_question_vignettes_referer' => 'عندما تعاين الاحضاءات، يمكنك ايضاً مشاهدة مصغرات عن المواقع الصادرة منها اذا كان الملحق <a href="@url@">Thumbsites</a> مثبت ونشط.',
	'info_question_vignettes_referer_oui' => 'عرض مصغرات عن مواقع مصدر الزيارات',
	'info_referer_oui' => 'تنشيط مصادر الزيارات',
	'info_tableaux' => 'الجداول',
	'info_visites' => 'زيارة:',
	'info_visites_plus_populaires' => 'إظهار الزيارات <b>لأكثر المقالات شعبية</b> و<b>لأحدث المقالات المنشورة:</ b>',
	'info_zoom' => 'تكبير-تصغير العرض',
	'item_gerer_statistiques' => 'إدارة إحصاءات الزيارات',

	// J
	'json' => 'json',

	// M
	'moyenne' => 'المتوسط',

	// O
	'onglet_origine_visites' => 'مصدر الزيارات',
	'onglet_repartition_debut' => 'منذ البداية',
	'onglet_repartition_lang' => 'التوزيع حسب اللغات',

	// R
	'resume' => 'ملخص',

	// T
	'texte_admin_effacer_stats' => 'هذا الأمر يحذف كل البيانات المرتبطة بإحصاءات  زيارات الموقع، بما فيها شعبية المقالات.',
	'texte_admin_effacer_toutes_stats' => 'يجذف الزر الأول كل الإحصاءات: الزيارات والشعبية والوصلات الآتية.',
	'texte_comment_lire_tableau' => 'تظهر مرتبة
المقال في تصنيف الشعبية، في
الهامش؛ وتظهر شعبية المقال (تقدير
لعدد الزيارات اليومية التي قد يسجلها اذا حافظ
تصفح الموقع على وتيرته الحالية) وعدد الزيارات
المسجلة منذ البداية، في المربع الذي
يظهر لدى حوم مؤشر الفأرة فوق العنوان.',
	'texte_signification' => 'القضبان الداكنة تجسد البنود المتراكمة (مجموع الأقسام الفرعية)، القضبان الفاتحة تجسد عدد الزيارات لكل قسم.',
	'titre_evolution_visite' => 'تطور الزيارات',
	'titre_liens_entrants' => 'الوصلات الآتية',
	'titre_page_statistiques' => 'الاحصاءات حسب القسم',
	'titre_page_statistiques_visites' => 'إحصاءات الزيارات',

	// V
	'visites' => 'الزيارات',
	'visites_annuelles' => 'عدد الزيارات السنوية',
	'visites_hebdomadaires' => 'عدد الزيارات الأسبوعية',
	'visites_journalieres' => 'عدد الزيارات اليومية',
	'visites_mensuelles' => 'عدد الزيارات الشهرية'
);

==> spip_4.3.1+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// A
	'archiver' => 'أرشفة',
	'archiver_concatener_explications' => 'ستقوم هذه العملية بتجميع إحصاءات زيارات المقالات:',
	'archiver_concatener_ignorer' => 'الزيارات الاحدث من @nb@ سنة لن تتأثر.',
	'archiver_concatener_par_an' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اول يوم من كل سنة.',
	'archiver_concatener_par_mois' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اليوم الأول من كل شهر.',
	'archiver_et_nettoyer' => 'أرشفة وتنظيف',
	'archiver_nettoyer' => 'تنظيف',
	'archiver_nettoyer_explications' => 'يحذف اسطر «المصادر» او «الزيارات» العائدة الى مقالات غير موجودة (او محذوفة) في قاعدة البيانات.',
	'archiver_nettoyer_referers_articles' => 'تنظيف مصادر المقالات referers_articles',
	'archiver_nettoyer_visites_articles' => 'تنظيف زيارات المقالات visites_articles',
	'archiver_nombre_lignes' => 'عدد الاسطر',
	'archiver_operation_longue' => 'يمكن ان تستغرق هذه العملية وقتاً طويلاً، خاصة لدي تنفيذها للمرة الاولي.',

	// B
	'bouton_effacer_referers' => 'حذف الوصلات الداخلة الآتية',
	'bouton_effacer_statistiques' => 'حذف كل الاحصاءات',

	// C
	'csv' => 'سي.اس.في.',

	// D
	'duree_annee_nb' => '@nb@ سنة',
	'duree_annee_un' => '@nb@ سنة',
	'duree_jour_nb' => '@nb@ يوم',
	'duree_jour_un' => '@nb@ يوم',
	'duree_mois_nb' => '@nb@ شهر',
	'duree_mois_un' => '@nb@ شهر',
	'duree_semaine_nb' => '@nb@ أسبوع',
	'duree_semaine_un' => '@nb@ أسبوع',

	// I
	'icone_evolution_visites' => 'تطور الزيارات <br />@visites@ زيارة ',
	'icone_repartition_actuelle' => 'إظهار التوزيع الحالي',
	'icone_repartition_visites' => 'توزيع الزيارات',
	'icone_statistiques_visites' => 'الإحصاءات',
	'info_affichier_visites_articles_plus_visites' => 'إظهار الزيارات المتعلقة <b> بأكثر المقالات زيارة منذ البداية:</ b>',
	'info_comment_lire_tableau' => 'كيفية قراءة هذا الرسم البياني',
	'info_forum_statistiques' => 'إحصاءات الزيارات',
	'info_graphiques' => 'الرسوم البيانية',
	'info_popularite_2' => 'شعبية الموقع:',
	'info_popularite_3' => 'الشعبية: @popularite@؛ الزيارات: @visites@',
	'info_popularite_5' => 'الشعبية:',
	'info_previsions' => 'توقعات:',
	'info_question_vignettes_referer' => 'عندما تعاين الاحضاءات، يمكنك ايضاً مشاهدة مصغرات عن المواقع الصادرة منها اذا كان الملحق <a href="@url@">Thumbsites</a> مثبت ونشط.',
	'info_question_vignettes_referer_oui' => 'عرض مصغرات عن مواقع مصدر الزيارات',
	'info_referer_oui' => 'تنشيط مصادر الزيارات',
	'info_tableaux' => 'الجداول',
	'info_visites' => 'زيارة:',
	'info_visites_plus_populaires' => 'إظهار الزيارات <b>لأكثر المقالات شعبية</b> و<b>لأحدث المقالات المنشورة:</ b>',
	'info_zoom' => 'تكبير-تصغير العرض',
	'item_gerer_statistiques' => 'إدارة إحصاءات الزيارات',

	// J
	'json' => 'json',

	// M
	'moyenne' => 'المتوسط',

	// O
	'onglet_origine_visites' => 'مصدر الزيارات',
	'onglet_repartition_debut' => 'منذ البداية',
	'onglet_repartition_lang' => 'التوزيع حسب اللغات',

	// R
	'resume' => 'ملخص',

	// T
	'texte_admin_effacer_stats' => 'هذا الأمر يحذف كل البيانات المرتبطة بإحصاءات  زيارات الموقع، بما فيها شعبية المقالات.',
	'texte_admin_effacer_toutes_stats' => 'يجذف الزر الأول كل الإحصاءات: الزيارات والشعبية والوصلات الآتية.',
	'texte_comment_lire_tableau' => 'تظهر مرتبة
المقال في تصنيف الشعبية، في
الهامش؛ وتظهر شعبية المقال (تقدير
لعدد الزيارات اليومية التي قد يسجلها اذا حافظ
تصفح الموقع على وتيرته الحالية) وعدد الزيارات
المسجلة منذ البداية، في المربع الذي
يظهر لدى حوم مؤشر الفأرة فوق العنوان.',
	'texte_signification' => 'القضبان الداكنة تجسد البنود المتراكمة (مجموع الأقسام الفرعية)، القضبان الفاتحة تجسد عدد الزيارات لكل قسم.',
	'titre_evolution_visite' => 'تطور الزيارات',
	'titre_liens_entrants' => 'الوصلات الآتية',
	'titre_page_statistiques' => 'الاحصاءات حسب القسم',
	'titre_page_statistiques_visites' => 'إحصاءات الزيارات',

	// V
	'visites' => 'الزيارات',
	'visites_annuelles' => 'عدد الزيارات السنوية',
	'visites_hebdomadaires' => 'عدد الزيارات الأسبوعية',
	'visites_journalieres' => 'عدد الزيارات اليومية',
	'visites_mensuelles' => 'عدد الزيارات الشهرية',
];
